@@ -115,7 +115,7 @@ impl<'a> ArtifactsEmitter<'a> {
         let artifacts_out_dir = {
             if cfg!(target_os = "linux") {
                 // RUNPATH is set to $origin/lib
-                self.artifacts_out_dir.join("lib")
+                mkdir(&self.artifacts_out_dir, Some("lib"))?
             } else {
                 self.artifacts_out_dir.clone()
             }
@@ -221,7 +221,7 @@ impl<'a> ArtifactsEmitter<'a> {
         } else {
             "flutter"
         };
-        let exe_path = Self::find_executable(executable);
+        let exe_path = Self::find_executable(executable).and_then(|p| p.canonicalize().ok());
         exe_path.and_then(|p| p.parent().map(Path::to_owned))
     }
 
